@@ -8,7 +8,7 @@ our @EXPORT_OK = qw(
     collect
 );
 
-our $VERSION = '0.0.16';
+our $VERSION = '0.0.17';
 
 use List::Util;
 use Scalar::Util qw(blessed);
@@ -328,7 +328,7 @@ sub intersect {
     my ($self, $other_collection) = @_;
 
     return $self->search({
-        $self->model->pk => $other_collection->lists($other_collection->model->pk),
+        $self->model->primary_key => $other_collection->lists($other_collection->model->primary_key),
     });
 }
 
@@ -408,7 +408,7 @@ sub missing {
     my ($self, $other_collection) = @_;
 
     return $self->exclude({
-        $self->model->pk => $other_collection->lists($other_collection->model->pk),
+        $self->model->primary_key => $other_collection->lists($other_collection->model->primary_key),
     });
 }
 
